@@ -79,6 +79,7 @@ def run_blind_test(
     threshold: float = 0.5,
     save: bool = False,
     save_path: str = None,
+    encoding: str = "UTF-8",
 ) -> pd.DataFrame:
     """Runs a blind test on the given assistant.
 
@@ -96,6 +97,7 @@ def run_blind_test(
         workspace_id (str): The workspace ID for the assistant.
         save (bool, optional): Whether to save the test results. Defaults to False.
         save_path (str, optional): The path to save the test results. Defaults to None.
+        encoding (str, optional): The encoding of the test file. Defaults to "UTF-8".
 
     Returns:
         pd.DataFrame: A DataFrame containing the results of the blind test.
@@ -105,12 +107,12 @@ def run_blind_test(
 
     print(f"=== {category} BLIND TEST STARTING ===")
     with open(path, "r") as f:
-        df = pd.read_csv(f, encoding="latin1")
+        df = pd.read_csv(f, encoding=encoding)
         for i in trange(len(df)):
 
             # Get original text and predicted intent
             text = df["text"][i]
-            prediction = df["intent"][i]
+            prediction = df["intent"][i].strip()
 
             # Get the response from the assistant
             response = assistant.message(
@@ -140,8 +142,8 @@ def run_blind_test(
 
             results.append(
                 {
-                    "original_text": df["text"][i],
-                    "predicted_intent": df["intent"][i].strip(),
+                    "original_text": text,
+                    "predicted_intent": prediction,
                     "actual_intent1": intent1.strip(),
                     "actual_confidence1": confidence1,
                     "actual_intent2": intent2.strip(),
